@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 import json
-import re
 
 from .exceptions import ItemNotFoundError
 from .item import Item, new_item
@@ -106,7 +105,9 @@ class Node(Item, ConfigurationMixIn, DeletionMixIn, RunScriptMixIn):
 
 class MasterComputer(Node):
     def __init__(self, jenkins, url):
-        super().__init__(jenkins, re.sub(r'/master/$', '/(master)/', url))
+        # rename built-in node: https://www.jenkins.io/doc/upgrade-guide/2.319/
+        name = 'master' if url.endswith('/master/') else 'built-in'
+        super().__init__(jenkins, f'{jenkins.url}computer/({name})/')
 
 
 class SlaveComputer(Node):
